@@ -39,6 +39,7 @@ protected:
     int GetStartIndex() { return _start; }
 
     virtual void Search(const QUrl &url, int start);
+    virtual void SearchEncodedUrl(const QString &endcoded_url, int start);
 
 public:
     Q_SIGNAL void SearchStarted(int search_task_id);
@@ -53,6 +54,9 @@ protected:
     Q_SLOT virtual void DownloadProgress(qint64, qint64);
     Q_SLOT virtual void NetworkError(QNetworkReply::NetworkError);
 
+protected:
+    QList<QTime> TimesFromString(const QList<QString> &time_strings);
+
 private:
     void FixLocation(QUrl *url);
 
